@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 import sys, os
 DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
     '..', '..', '..', '..', '..', 'trytond')))
@@ -11,7 +10,8 @@ if os.path.isdir(DIR):
 import unittest
 from decimal import Decimal
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view
+from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
+    test_depends
 from trytond.transaction import Transaction
 
 
@@ -37,12 +37,19 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         test_view('currency')
 
+    def test0006depends(self):
+        '''
+        Test depends.
+        '''
+        test_depends()
+
     def test0010currencies(self):
         '''
         Create currencies
         '''
 
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu1_id = self.currency.create({
                 'name': 'cu1',
                 'symbol': 'cu1',
@@ -63,7 +70,7 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Check grouping
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             cu1_id = self.get_currency('cu1')
 
             self.assertRaises(Exception, self.currency.write, cu1_id, 
@@ -82,7 +89,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Create rates.
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
 
@@ -108,7 +116,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Rate unicity
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             today = self.date.today()
 
             cu_id = self.currency.create({
@@ -135,7 +144,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Simple conversion
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
 
@@ -151,7 +161,7 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion with rounding on non-finite decimal representation
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
 
@@ -165,7 +175,7 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Same without rounding
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
 
@@ -179,7 +189,7 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion to the same currency
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             cu1_id = self.get_currency('cu1')
     
             amount = Decimal("10")
@@ -191,7 +201,7 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion with zero amount
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
     
@@ -205,7 +215,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion with zero rate
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu1_id = self.get_currency('cu1')
             cu2_id = self.get_currency('cu2')
     
@@ -227,7 +238,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion with missing rate
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu1_id = self.get_currency('cu1')
             cu3_id = self.currency.create({
                 'name': 'cu3',
@@ -247,7 +259,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Conversion with both missing rate
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             cu3_id = self.currency.create({
                 'name': 'cu3',
                 'symbol': 'cu3',
@@ -269,7 +282,8 @@ class CurrencyTestCase(unittest.TestCase):
         '''
         Test deletion of currency deletes rates
         '''
-        with Transaction().start(DB_NAME, USER, CONTEXT) as transaction:
+        with Transaction().start(DB_NAME, USER,
+                context=CONTEXT) as transaction:
             codes = ['cu%s' % (i + 1) for i in range(2)]
             currency_ids = [self.get_currency(i) for i in codes]
             self.currency.delete(currency_ids)
